@@ -106,6 +106,8 @@ class AdsAPI(object):
     def make_request(self, path, method, args=None, files=None, batch=False, raw_path=False):
         """Makes a request against the Facebook Ads API endpoint."""
         args = dict(args or {})
+        args = {k.encode('utf-8'): unicode(v).encode('utf-8')
+                for k, v in args.items()}
 
         if batch:
             # Then just return a dict for the batch request
@@ -149,6 +151,8 @@ class AdsAPI(object):
         args = {}
         args['access_token'] = self.access_token
         args['batch'] = json.dumps(batch)
+        args = {k.encode('utf-8'): unicode(v).encode('utf-8')
+                for k, v in args.items()}
         logger.info('Making a batched request with %s' % args)
         try:
             f = urllib2.urlopen(FACEBOOK_API, urllib.urlencode(args))
@@ -599,6 +603,14 @@ class AdsAPI(object):
         args = {'fields': 'access_token'}
         return self.make_request(path, 'GET', args, batch=batch)
 
+    def get_page_post(self, page_post_id, fields=None, batch=False):
+        """Returns data for the give page post."""
+        path = '%s' % page_post_id
+        args = {}
+        if fields:
+            args['fields'] = json.dumps(fields)
+        return self.make_request(path, 'GET', args, batch=batch)
+
     def create_adimage(self, account_id, image_data, batch=False):
         """Creates an ad image in the given ad account."""
         path = 'act_%s/adimages' % account_id
